@@ -1,5 +1,6 @@
 '''File for handling all operations relating to the Address datatype'''
 
+import random
 from faker import Faker
 
 
@@ -8,7 +9,8 @@ def generateAddress() -> dict:
     address_data = {
         'line': [generateLineAddress()],
         'city': generateCityAddress(),
-        'state': generateStateAddress()
+        'state': generateStateAddress(),
+        'postalCode': generatePostalCodeAddress()
     }
     return address_data
 
@@ -29,3 +31,12 @@ def generateStateAddress():
     '''Function for generating a state in a FHIR Address'''
     fake = Faker()
     return fake.state()
+
+
+def generatePostalCodeAddress():
+    '''Function for generating a postal code in a FHIR Address'''
+    rand_str = str(random.randint(1, 99950))
+    if len(rand_str) != 5:
+        leading_zeros = ''.join(['0' for x in range(0, 5 - len(rand_str))])
+        rand_str = leading_zeros + rand_str
+    return rand_str
